# RPM specfile for the UpdateBrowsCap package
# Copyright 2008 Parliament Hill Computers Ltd, all rights reserved.
# Author: ADDW December 2008
# SCCS: @(#)UpdateBrowsCap.spec	1.16 04/15/15 14:44:16
# Note that the version number (1.16 - SCCS %-I-% (sans -)) of this file defines the package version #. It is used in the Makefile.

%define name UpdateBrowsCap
%define version 1.16
%define release 1.1

Summary: Keep the PHP Browser capability database up to date
Name: %{name}
Version: %{version}
Release: %{release}
# Should use SCCS for below:
Source: http://www.phcomp.co.uk/Downloads/UpdateBrowsCap-%{version}.tar.gz
Vendor: %{vendor}
URL: %{phcl_url}
BuildArchitectures: noarch


License: GPL
# Copyright: GPL --- this is old/unsupported syntax

Packager: %{packager}

Group: Development/Languages
BuildRoot: %{_builddir}/%{name}-root
# Don't make it depend on httpd - although I can't see why you would use it without
%if 0%{?rhel} >= 5
Requires: ksh coreutils php grep curl vixie-cron
%else
Requires: pdksh coreutils php grep curl vixie-cron
%endif
BuildRequires: make

# This is only needed if we want to build a relocatable RPM:
#Prefix: %{_prefix}

%description

Ensure that the PHP browscap is up to date from Gary Joel Keith's web site.
This is used by the php function get_browser(); the database changes frequently,
as often as weekly. This is intended to be run from cron.
The web server (Apache) is restarted.

Gary's site is here:

	http://browsers.garykeith.com/downloads.asp

See also:

	http://updates.browserproject.com/

%prep
%setup -q

%build
%install
rm -rf $RPM_BUILD_ROOT
make DESTDIR=$RPM_BUILD_ROOT%{_prefix} VERSION=%{version} install

%post

# Install a cron job to run UpdateBrowsCap
# Do NOT put this into /etc/cron.weekly/ because every machine that has this package would
# hit Gary's site at the same time - and kill it.
# Randomise the time that the sript is run.
if [ $1 = 1 ]
then	weekday=$( expr $RANDOM % 7 )
	hour=$( expr $RANDOM % 24 )
	minute=$( expr $RANDOM % 60 )
	tmpf=/tmp/UBC.$$
	trap "rm -f $tmpf" 0

	crontab -l > $tmpf 2>/dev/null || true
	if grep -q UpdateBrowsCap $tmpf
	then	fetch=n	# There is already something there
	else	echo -e "$minute\t$hour\t*\t*\t$weekday\tUpdateBrowsCap -d" >> $tmpf
		crontab $tmpf
		fetch=y
	fi

	NoHttpd=-d	# Default not restart web server

	# If the php.ini contains a commented out browscap line, comment it in & restart
	# the web server.
	# Until the browscap file exists, php will winge.
	PHP_ini=$( php -r 'print get_cfg_var("cfg_file_path");' 2>/dev/null )
	if [ -n "$PHP_ini" ] && grep -q '^;browscap' $PHP_ini
	then	sed -e '/^;browscap/s/;//' $PHP_ini > $tmpf
		cat $tmpf > $PHP_ini

		# See what we get, it might not be clever, something like 'extra/browscap.ini':
		BrowscapFile=$( php -r 'print ini_get("browscap");' 2>/dev/null )
		case $BrowscapFile in
		'')	# cannot really do much
			echo "Please set a 'browscap' in $PHP_ini"
			BrowscapFile=
			;;
		/*)	: Looks good
			;;
		*)	# Need to replace with something decent, use the same directory as
			# contains session directory
			SessDir=$( php -r 'print ini_get("session.save_path");' 2>/dev/null )
			case $SessDir in
			'')	# This is broken!
				echo "Please set a 'browscap' in $PHP_ini"
				BrowscapFile=
				;;
			/*)	BcDir=$( dirname $SessDir )
				sed -e "/^browscap.*/s::browscap = $BcDir/browscap.ini:" $PHP_ini > $tmpf
				cat $tmpf > $PHP_ini
				BrowscapFile=$BcDir/browscap.ini
				;;
			*)	echo "Please set a 'browscap' in $PHP_ini"
				BrowscapFile=
				;;
			esac
		esac

		# Keep PHP happy, create empty file, also fill it later
		[ -n "$BrowscapFile" -a ! -f "$BrowscapFile" ] && fetch=y && touch $BrowscapFile

		# Allow it to be restarted if it is running
		service httpd status > /dev/null && NoHttpd=
	fi

	# This may take some time, so fire into background.
	# It might also generate errors if the php.ini hacking above did not happen:
	[ $fetch = y ] && UpdateBrowsCap $NoHttpd >/dev/null 2>&1 &	# No output the RPM spec says!
fi

%preun

# Remove the cron entry, don't touch the crontab unless there is something to zap.
if [ $1 = 0 ]
then	tmpf=/tmp/UBC.$$
	trap "rm -f $tmpf" 0
	crontab -l > $tmpf 2>/dev/null || true
	if grep -q 'UpdateBrowsCap' $tmpf
	then	sed -e '/UpdateBrowsCap/d' $tmpf | crontab
	fi
fi

# Don't remove the browscap line from php.ini - they could be updating it some other way.
# Anyway: it will just slowly get out of date

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root)
%{_bindir}/UpdateBrowsCap
%doc README Contributors License Hacks

%changelog
* Wed Apr 15 2015 Alain Williams <addw@phcomp.co.uk>
- Update to use the BCP site. Add --type option
* Wed Jun 20 2012 Alain Williams <addw@phcomp.co.uk>
- Fix another option parsing error.
* Wed Jun 20 2012 Alain Williams <addw@phcomp.co.uk>
- Fix option parsing error.
- Add --force option.
* Mon May 21 2012 Alain Williams <addw@phcomp.co.uk>
- Add -k --insecure option
- Tweak some messages & help. Replace option parsing with something more flexible.
* Fri Feb 02 2012 Alain Williams <addw@phcomp.co.uk>
- Fix variable not set bug
* Fri Nov 25 2011 Alain Williams <addw@phcomp.co.uk>
- Implement -b option - allow location of the browscap file to be specified from the command line.
* Mon Feb 07 2011 Alain Williams <addw@phcomp.co.uk>
- Update location from where to check/download
* Mon Aug 10 2009 Alain Williams <addw@phcomp.co.uk>
  Update comments; Be a bit smarter on restarting the web server.
* Thu Aug 06 2009 Alain Williams <addw@phcomp.co.uk>
- Configure the browscap line in php.ini, restart the web server & get the initial browscap
* Thu Aug 06 2009 Alain Williams <addw@phcomp.co.uk>
- Version checker URL changed
  Fix bad Summary in spec file
* Thu Aug 06 2009 Alain Williams <addw@phcomp.co.uk>
- Install a cron entry
* Thu Aug 06 2009 Alain Williams <addw@phcomp.co.uk>
- First spec file
